@@ -28,13 +28,13 @@ class Document(models.Model):
         filename = ''.join([c for c in unicodedata.normalize('NFKD', filename)
                            if not unicodedata.combining(c)])
 
-        return f'documents/{filename}'
+        return f'{self.project.local_id_name}/documents/{filename}'
 
     project = models.ForeignKey(Project, on_delete=models.CASCADE)
 
     document_type = models.ForeignKey(DocumentType, on_delete=models.PROTECT)
 
-    filehandle = models.FileField(upload_to=get_upload_path)
+    filehandle = models.FileField(upload_to=get_upload_path, max_length=255)
     filename = models.CharField(max_length=255)
 
     uploaded_at = models.DateTimeField(auto_now_add=True, editable=False)
